@@ -88,7 +88,7 @@ rep_lin_ <- function(e, or=TRUE, h=new.env()){
   l <- left(e)
   r <- right(e)
 
-  if (is.atomic(e) || is.symbol(e)){
+  if (is.atomic(e) || is.symbol(e) || is.null(e)){
     return(e)
   }
 
